# FIREBASE PUSH NOTIFICATION

## INTRODUCTION

Provides a simple way to use Firebase Cloud Messaging.

## INSTALLATION

Install as usual, see
 <https://www.drupal.org/docs/8/extending-drupal-8/installing-drupal-8-modules>
 for more information.

## CONFIGURATION

The module has a simple configuration form, where you provide Server Key and
Sender ID.

## HOW TO USE

In order to send the push notification message with data:

```php
// Token is generated by app. You'll have to send the token to Drupal.
$fakeToken = 'e3vUiwcvkpY:APA91bEDZzKTIkaL0e-UTwiV6EGi1m5J5PrDMxejm6-d85vdwAgd';
$messageService = \Drupal::service('firebase.message');
$messageService->setRecipients($fakeToken);
$messageService->setNotification([
  'title' => 'Title goes here',
  'body' => 'Body goes here',
  'badge' => 1,
  'icon' => 'optional-icon',
  'sound' => 'optional-sound',
  'click_action' => 'optional-action',
]);
$messageService->setData([
  'score' => '3x1',
  'date' => '2017-10-10',
  'optional' => 'Data is used to send silent pushes. Otherwise, optional.',
]);
$messageService->setOptions(['priority' => 'normal']);
$messageService->send();
```

Token is generated by the app. Read <https://firebase.google.com/docs/auth/admin/verify-id-tokens> for more information.
In data message and notification you can include all options which described here <https://firebase.google.com/docs/cloud-messaging/http-server-ref>

For sending one message to multiple devices you can use groups, topics or just send to multiple tokens.
Example for creation group:

```php
$groupService = \Drupal::service('firebase.group_manager');
$groupService->createGroup('uniqueGroupName', ['token 1', 'token 2', 'token 3' ...]);
```

Group service will return to you notification key, which need store and use as recipient in message service.

Example for adding new device to group:

```php
$groupService = \Drupal::service('firebase.group_manager');
$groupService->addToGroup('uniqueGroupName', 'groupToken', ['token 1', 'token 2', 'token 3' ...]);
```

Example for remove device from group:

```php
$groupService = \Drupal::service('firebase.group_manager');
$groupService->removeFromGroup('uniqueGroupName', 'groupToken', ['token 1', 'token 2', 'token 3' ...]);
```

Example for creation topics need subscribe token on topic before sending. See example:

```php
$topicManager = \Drupal::service('firebase.topic_manager');
$topicManager->processTopicSubscription('topicName', ['token 1', 'token 2', 'token 3' ...], FirebaseTopicManagerService::SUBSCRIBE_ENDPOINT);
// And after subscribtion devices on topic you can use this topic in message service.
$messageService = \Drupal::service('firebase.message');
$messageService->setTopics('topicName');
// and after build notification message or data message and send him.
```

For unsubscribe use endpoint `FirebaseTopicManagerService::UNSUBSCRIBE_ENDPOINT`

Also you can use condition for topics. Example:

```php
$messageService = \Drupal::service('firebase.message');
$messageService->setTopics(['first', 'second', 'third']);
// Need to send message to all devices which subscribed on topics `first` AND (`second` OR `third`)
$messageService->setCondition('%s && (%s || %s)');
$messageService->setNotification([...])->send();
```

## MAINTAINERS

Current maintainers:

* Leonardo Paccanaro - <https://www.drupal.org/user/1901878>
